use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Erlang
POSIXish
Stevan
Little
stevan
יובל
קוג
Yuval
Kogman
nothingmuch
Karen
Etheridge
ether
Justin
Hunter
justin
Jan
Bieron
jbieron
lib
POE
Component
Supervisor
Handle
Interface
Proc
Session
LogDispatch
Supervised
